# Introduction to the basic usage of a ecVKOGA model.

import numpy as np
import matplotlib.pyplot as plt
from sklearn.model_selection import train_test_split
from utils.ecVKOGA import ecVKOGA

# Define a dataset `(X, y)` to run some experiments.
x = np.linspace(0, 1, 31)
y = np.linspace(0, 1, 31)
xv, yv = np.meshgrid(x, y)

f1 = lambda x, y: y
f2 = lambda x, y: x         # these are the derivatives of a potential Phi(x,y) = x*y

X = np.hstack([xv.reshape(-1,1), yv.reshape(-1,1)])
y = np.hstack([f1(X[:, [0]], X[:, [1]]), f2(X[:, [0]], X[:, [1]])])

kernel_par = 1

# We split the dataset
X_train, X_test, y_train, y_test = train_test_split(X, y, test_size=0.2, random_state=2)

# We start by defining a VKOGA model with default parameters.
model = ecVKOGA(kernel_par=kernel_par, max_iter=30)

# The VKOGA model can now be trained on the dataset using the `fit` method:
_ = model.fit(X_train, y_train)

# Get some information
f_max, p_max = model.train_hist['f'], model.train_hist['p']

# Calculate error on test set
y_test_predict = model.predict_tmp(X_test)
max_error_test = np.max(np.abs(y_test_predict - y_test))

# Plots on the decay of the error
plt.figure(1)
plt.clf()
plt.plot(np.arange(1, len(f_max)+1), f_max)
plt.plot([1, len(f_max)], [max_error_test**2, max_error_test**2])
plt.yscale('log')
plt.title('fmax')

plt.figure(2)
plt.clf()
plt.plot(np.arange(1, len(p_max)+1), p_max)
plt.yscale('log')
plt.title('pmax')




